package net.wanji.opt.controllerv2.strategy;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;
import net.wanji.common.framework.i18n.I18nResourceBundle;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.opt.entity.eventoptimize.TEventOptimizeInfo;
import net.wanji.opt.entity.strategy.StrategyParameterConfig;
import net.wanji.opt.entity.strategy.StrategyPriorityDailyInfo;


import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import net.wanji.opt.entity.strategy.dto.StrategyPriorityGroup;
import net.wanji.opt.servicev2.strategy.StrategyPriorityService;
import net.wanji.opt.synthesis.pojo.StrategyFactoryEntity;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import net.wanji.opt.api.ResultGenerator;



import javax.validation.Valid;
import javax.ws.rs.core.MediaType;
import java.util.List;
import java.util.Map;

/**
* <p>
* 策略优先级日计划详情表 前端控制器
* </p>
*
* @author fengyi
* @since 2025-03-28
*/
@Api(tags = "策略管理")
@RestController
@RequestMapping("/strategy-priority")
@Slf4j
public class StrategyPriorityController {


    @Autowired
    private StrategyPriorityService strategyPriorityService;



    //策略管理-路口列表
    @ApiOperation(value = "策略管理-路口列表", notes = "查询全部记录",  produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON,hidden = false)
    @ApiImplicitParams({
//            @ApiImplicitParam(name = "crossId", value = "路口id", required = false, dataType = "String"),
    })
    @GetMapping("/strategyCrossList")
    public JsonViewObject pageStrategyCrossList(){
        JsonViewObject jsonView = JsonViewObject.newInstance();
        try {
            List<StrategyPriorityDailyInfo> retLineData=strategyPriorityService.pageStrategyCrossList();
            jsonView.success(retLineData);
        }catch (Exception e){
            jsonView.fail(I18nResourceBundle.getConstants("GET_FAILED_MSG"));
            log.error("{} getAll error", this.getClass().getSimpleName(), e);
        }
        return  jsonView;

    }

    @ApiOperation(value = "策略管理-策略名称", notes = "查询全部记录",  produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON,hidden = false)
    @GetMapping("/strategyList")
    public JsonViewObject getStrategyList(){
        JsonViewObject jsonView = JsonViewObject.newInstance();
        try {
            List<StrategyFactoryEntity> retLineData=strategyPriorityService.getStrategyList();
            jsonView.success(retLineData);
        }catch (Exception e){
            jsonView.fail(I18nResourceBundle.getConstants("GET_FAILED_MSG"));
            log.error("{} getAll error", this.getClass().getSimpleName(), e);
        }
        return  jsonView;

    }

    @ApiOperation(value = "策略管理-场景", notes = "查询全部记录",  produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON,hidden = false)
    @GetMapping("/sceneList")
    public JsonViewObject getSceneList(Integer type){
        JsonViewObject jsonView = JsonViewObject.newInstance();
        try {
            List<StrategyFactoryEntity> retLineData=strategyPriorityService.getSceneList(type);
            jsonView.success(retLineData);
        }catch (Exception e){
            jsonView.fail(I18nResourceBundle.getConstants("GET_FAILED_MSG"));
            log.error("{} getAll error", this.getClass().getSimpleName(), e);
        }
        return  jsonView;
    }

    @ApiOperation(value = "策略管理-厂商", notes = "查询全部记录",  produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON,hidden = false)
    @GetMapping("/companyList")
    public JsonViewObject getCompanyList(){
        JsonViewObject jsonView = JsonViewObject.newInstance();
        try {
            List<StrategyFactoryEntity> retLineData=strategyPriorityService.getCompanyList();
            jsonView.success(retLineData);
        }catch (Exception e){
            jsonView.fail(I18nResourceBundle.getConstants("GET_FAILED_MSG"));
            log.error("{} getAll error", this.getClass().getSimpleName(), e);
        }
        return  jsonView;
    }

    @ApiOperation(value = "策略管理-策略路口干线优先级批量保存", notes = "批量保存",  produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON,hidden = false)
    @ApiImplicitParams({
           @ApiImplicitParam(name = "dataList", value = "优先级配置数据", required = false, dataType = "String"),
    })
    @PostMapping("/savePriority")
    public JsonViewObject savePriority(@RequestBody List<StrategyPriorityGroup>dataList){
        JsonViewObject jsonView = JsonViewObject.newInstance();
        try {
               strategyPriorityService.savePriority(dataList);
                jsonView.success();
        } catch (Exception e) {
            jsonView.fail(I18nResourceBundle.getConstants("SAVE_FAILED_MSG"));
            log.error("{} StrategyPriorityController-savePriority", this.getClass().getSimpleName(), e);
        }
        return jsonView;
    }

    @ApiOperation(value = "策略管理-策略路口干线优先级数据回显", notes = "数据回显",  produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON,hidden = false)
    @ApiImplicitParams({
           @ApiImplicitParam(name = "crossId", value = "路口id", required = false, dataType = "String"),
            @ApiImplicitParam(name = "greenId", value = "干线id", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "type", value = "类型", required = true, dataType = "Integer"),
    })
    @GetMapping("/getPriorityConfig")
    public JsonViewObject getPriorityData(@RequestParam(required = false) String crossId,@RequestParam(required = false) Integer greenId,
                                          @RequestParam(required = true) Integer type){
        JsonViewObject jsonView = JsonViewObject.newInstance();
        try {
            List<StrategyFactoryEntity>list=strategyPriorityService.getPriorityData(crossId,greenId,type);
            jsonView.success(list);
        } catch (Exception e) {
            jsonView.fail(I18nResourceBundle.getConstants("SAVE_FAILED_MSG"));
            log.error("{} StrategyPriorityController-getPriorityData", this.getClass().getSimpleName(), e);
        }
        return jsonView;
    }

    @ApiOperation(value = "策略管理-策略计划表路口干线批量保存", notes = "批量保存",  produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON,hidden = false)
    @ApiImplicitParams({
            @ApiImplicitParam(name = "dailyPlanDetails", value = "日计划配置数据", required = false, dataType = "String"),
    })
    @PostMapping("/savePlanConfig")
    public JsonViewObject savePlanConfig(@RequestBody List<StrategyPriorityGroup>dailyPlanDetails){
        JsonViewObject jsonView = JsonViewObject.newInstance();
        try {
            strategyPriorityService.savePlanConfig(dailyPlanDetails);
            jsonView.success();
        } catch (Exception e) {
            jsonView.fail(I18nResourceBundle.getConstants("SAVE_FAILED_MSG"));
            log.error("{} StrategyPriorityController-savePlanConfig", this.getClass().getSimpleName(), e);
        }
        return jsonView;
    }

    @ApiOperation(value = "策略管理-计划配置路口干线数据回显", notes = "数据回显",  produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON,hidden = false)
    @ApiImplicitParams({
            @ApiImplicitParam(name = "crossId", value = "路口id", required = false, dataType = "String"),
            @ApiImplicitParam(name = "greenId", value = "干线id", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "type", value = "类型", required = true, dataType = "Integer"),
    })
    @GetMapping("/getPlanConfigData")
    public JsonViewObject getPlanConfigData(@RequestParam(required = false) String crossId,@RequestParam(required = false) Integer greenId,
                                            @RequestParam(required = true) Integer type){
        JsonViewObject jsonView = JsonViewObject.newInstance();
        try {
            List<StrategyPriorityDailyInfo>list=strategyPriorityService.getPlanConfigData(crossId,greenId,type);
            jsonView.success(list);
        } catch (Exception e) {
            jsonView.fail(I18nResourceBundle.getConstants("SAVE_FAILED_MSG"));
            log.error("{} StrategyPriorityController-getPriorityData", this.getClass().getSimpleName(), e);
        }
        return jsonView;
    }

    @ApiOperation(value = "策略管理-策略参数配置批量保存", notes = "批量保存",  produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON,hidden = false)
    @ApiImplicitParams({
            @ApiImplicitParam(name = "strategyPriorityGroup", value = "参数配置数据", required = false, dataType = "String"),
    })
    @PostMapping("/saveParamterConfig")
    public JsonViewObject saveParamterConfig(@RequestBody StrategyPriorityGroup strategyPriorityGroup){
        JsonViewObject jsonView = JsonViewObject.newInstance();
        try {
            strategyPriorityService.saveParamterConfig(strategyPriorityGroup);
            jsonView.success();
        } catch (Exception e) {
            jsonView.fail(I18nResourceBundle.getConstants("SAVE_FAILED_MSG"));
            log.error("{} StrategyPriorityController-saveParamterConfig", this.getClass().getSimpleName(), e);
        }
        return jsonView;
    }


    @ApiOperation(value = "策略管理-参数配置数据回显", notes = "数据回显",  produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON,hidden = false)
    @ApiImplicitParams({
            @ApiImplicitParam(name = "crossId", value = "路口id", required = true, dataType = "String")
    })
    @GetMapping("/getParamConfigData")
    public JsonViewObject getParamConfigData(@RequestParam(required = true) String crossId){
        JsonViewObject jsonView = JsonViewObject.newInstance();
        try {
            List<StrategyParameterConfig>list=strategyPriorityService.getParamConfigData(crossId);
            jsonView.success(list);
        } catch (Exception e) {
            jsonView.fail(I18nResourceBundle.getConstants("SAVE_FAILED_MSG"));
            log.error("{} StrategyPriorityController-getPriorityData", this.getClass().getSimpleName(), e);
        }
        return jsonView;
    }

    /*
    策略管理-干线列表
    */
    @ApiOperation(value = "策略管理-干线列表", notes = "查询全部记录",  produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON,hidden = false)
    @GetMapping("/getStrategyGreenWave")
    public JsonViewObject getStrategyGreenWave(){
        JsonViewObject jsonView = JsonViewObject.newInstance();
        try {
            List<StrategyPriorityDailyInfo> retLineData=strategyPriorityService.getStrategyGreenWave();
            jsonView.success(retLineData);
        }catch (Exception e){
            jsonView.fail(I18nResourceBundle.getConstants("GET_FAILED_MSG"));
            log.error("{} getStrategyGreenWave error", this.getClass().getSimpleName(), e);
        }
        return  jsonView;

    }
}